@@ -2,7 +2,8 @@
 
 
 package HiD::App::Command::config;
-$HiD::App::Command::config::VERSION = '1.95';
+our $AUTHORITY = 'cpan:GENEHACK';
+$HiD::App::Command::config::VERSION = '1.96';
 use Moose;
 extends 'HiD::App::Command';
 use namespace::autoclean;
@@ -14,12 +15,13 @@ use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
 
+use Data::Printer return_value => 'dump';
+
 sub _run {
   my( $self , $opts , $args ) = @_;
 
   $args = [ 'config' ] unless $args->[0];
 
-  use DDP;
   my $out;
   $out .= p $self->hid->$_ foreach @$args;
 
@@ -67,7 +69,7 @@ sub commands.
 
 =head1 VERSION
 
-version 1.95
+version 1.96
 
 =head1 AUTHOR
 
