@@ -2,7 +2,8 @@
 
 
 package HiD::File;
-$HiD::File::VERSION = '1.95';
+our $AUTHORITY = 'cpan:GENEHACK';
+$HiD::File::VERSION = '1.96';
 use Moose;
 with 'HiD::Role::IsPublished';
 use namespace::autoclean;
@@ -30,7 +31,17 @@ sub publish {
 }
 
 # used to populate the 'url' attr in Role::IsPublished
-sub _build_url { return shift->input_filename }
+sub _build_url {
+  my $self = shift;
+
+  my $source = $self->source;
+
+  my $path_frag = $self->input_filename;
+  $path_frag =~ s/^$source//;
+
+  return path( $path_frag )->stringify;
+}
+
 
 __PACKAGE__->meta->make_immutable;
 1;
@@ -70,7 +81,7 @@ well if you're trying to figure out how an object from this class works.
 
 =head1 VERSION
 
-version 1.95
+version 1.96
 
 =head1 AUTHOR
 
