@@ -2,7 +2,8 @@
 
 
 package HiD::Generator::AtomFeed;
-$HiD::Generator::AtomFeed::VERSION = '1.95';
+our $AUTHORITY = 'cpan:GENEHACK';
+$HiD::Generator::AtomFeed::VERSION = '1.96';
 use Moose;
 with 'HiD::Generator';
 
@@ -64,7 +65,7 @@ sub _new_entry {
   $entry->author($post->author);
   $entry->link($post->url);
   $entry->id($post->baseurl . $post->url);
-  $entry->updated($post->date);
+  $entry->modified($post->date);
   $entry->summary($post->description) if $post->description;
   $entry->content($post->converted_content);
 
@@ -163,7 +164,7 @@ See the documentation above to understand what each key controls.
 
 =head1 VERSION
 
-version 1.95
+version 1.96
 
 =head1 AUTHOR
 
