@@ -2,7 +2,8 @@
 
 
 package HiD::Role::IsPost;
-$HiD::Role::IsPost::VERSION = '1.95';
+our $AUTHORITY = 'cpan:GENEHACK';
+$HiD::Role::IsPost::VERSION = '1.96';
 use Moose::Role;
 use namespace::autoclean;
 
@@ -91,9 +92,10 @@ has date => (
       ( $year , $month , $day ) = $self->input_filename
         =~ m|^.*?/([0-9]{4})-([0-9]{1,2})-([0-9]{1,2})-|;
       return DateTime->new(
-        year  => $year ,
-        month => $month ,
-        day   => $day
+        year      => $year ,
+        month     => $month ,
+        day       => $day ,
+        time_zone => 'UTC' ,
       );
     }
   },
@@ -176,21 +178,30 @@ sub _build_title {
 }
 
 
-has twitter => (
-  is => 'ro' ,
-  isa => 'Maybe[Str]' ,
-  lazy => 1 ,
-  builder => '_build_twitter' ,
+has twitter_handles => (
+  is      => 'ro' ,
+  isa     => 'ArrayRef[Str]' ,
+  lazy    => 1 ,
+  builder => '_build_twitter_handles' ,
+  traits  => [ 'Array' ],
+  handles => {
+      has_twitter_handles => 'count',
+      all_twitter_handles => 'elements',
+  },
 );
 
-sub _build_twitter {
+sub _build_twitter_handles {
   my $self = shift;
 
-  my $twitter = $self->get_metadata( 'twitter' );
+  my $t = $self->get_metadata('twitter');
 
-  return defined $twitter ? $twitter : undef;
+  return ref $t ? $t : [ $t ? $t : () ];
 }
 
+
+sub twitter { ($_[0]->all_twitter_handles)[0] }
+
+
 around BUILDARGS => sub {
   my $orig  = shift;
   my $class = shift;
@@ -222,7 +233,6 @@ sub is_draft {
   return ( $self->input_filename =~ /^$drafts_dir/ ) ? 1 : 0;
 }
 
-
 no Moose::Role;
 1;
 
@@ -263,7 +273,8 @@ DateTime object for this post.
 
 =head2 description
 
-A one-line synopsis of the post (used, e.g., for metadata information used by Open Graph)
+A one-line synopsis of the post (used, e.g., for metadata information used by
+Open Graph)
 
 =head2 excerpt
 
@@ -275,10 +286,28 @@ want to list the full post on the front page.
 
 =head2 title
 
-=head2 twitter
+=head2 twitter_handles
+
+Returns an arrayref of the twitter handles passed via
+the C<twitter> parameter.
 
 =head1 METHODS
 
+=head2 has_twitter_handles
+
+Returns c<true> if the post has any twitter handles associated with it, C<false>
+otherwise.
+
+=head2 all_twitter_handles
+
+Returns the list of the twitter handles associated with the post.
+
+=head2 twitter
+
+DEPRECATED: use <twitter_handles> instead.
+
+Returns the first twitter handle given to C<twitter>.
+
 =head2 all_tags
 
 Returns all tags for this post, joined together with commas
@@ -290,7 +319,7 @@ folder or not.
 
 =head1 VERSION
 
-version 1.95
+version 1.96
 
 =head1 AUTHOR
 
